@@ -1,10 +1,19 @@
 import contextlib
 import tempfile
 from pathlib import Path
+from typing import Iterable
+
+import build
+import build.env
 
 from slap.application import Application, Command, option
+from slap.install.installer import PipInstaller
 from slap.plugins import ApplicationPlugin
-from slap.python.pep517 import BuildBackend
+
+
+def flatten(it: Iterable[Iterable[str]]) -> Iterable[str]:
+    for item in it:
+        yield from item
 
 
 class PublishCommandPlugin(Command, ApplicationPlugin):
@@ -24,6 +33,12 @@ class PublishCommandPlugin(Command, ApplicationPlugin):
 
     name = "publish"
     options = [
+        option(
+            "python",
+            flag=False,
+            description="use this Python executable to build the distribution but do not automatically install build "
+            "requirements into it; if not specified a temporary build environment is created",
+        ),
         option("repository", "r", flag=False, default="pypi"),
         option("repository-url", flag=False),
         option("sign", "s"),
@@ -61,24 +76,33 @@ class PublishCommandPlugin(Command, ApplicationPlugin):
             if build_dir is None:
                 build_dir = stack.enter_context(tempfile.TemporaryDirectory())
 
+            executable = self.option("python")
+            if not executable:
+                isolated_env = stack.enter_context(build.env.IsolatedEnvBuilder())
+                executable = isolated_env.executable
+            else:
+                isolated_env = None
+
             for project in self.app.repository.projects():
+                if isolated_env:
+                    isolated_env.install(
+                        list(flatten(PipInstaller.dependency_to_pip_arguments(x) for x in project.dependencies().build))
+                    )
                 if not project.is_python_project:
                     continue
 
                 self.line(f"Build <info>{project.dist_name()}</info>")
-                backend = BuildBackend(
-                    project.pyproject_toml.value()["build-system"]["build-backend"], project.directory, Path(build_dir)
-                )
+                builder = build.ProjectBuilder(project.directory, executable)
 
-                sdist = backend.build_sdist()
+                sdist = Path(builder.build("sdist", build_dir))
                 self.line(f"  <comment>{sdist.name}</comment>")
-                wheel = backend.build_wheel()
+                wheel = Path(builder.build("wheel", build_dir))
                 self.line(f"  <comment>{wheel.name}</comment>")
 
                 distributions += [sdist, wheel]
 
             if not self.option("dry"):
-                self.line(f"Publishing")
+                self.line("Publishing")
                 kwargs = {option.name.replace("-", "_"): self.option(option.name) for option in self.options}
                 kwargs["repository_name"] = kwargs.pop("repository")
                 settings = Settings(**kwargs)
