@@ -7,7 +7,6 @@ import typing as t
 
 from slap.ext.project_handlers.base import PyprojectHandler
 from slap.project import Dependencies, Package, Project
-from slap.python.dependency import Dependency, PypiDependency
 
 if t.TYPE_CHECKING:
     from slap.python.dependency import Dependency
@@ -69,6 +68,7 @@ class PoetryProjectHandler(PyprojectHandler):
             run=[d for d in dependencies if d.name != "python"],
             dev=parse_dependencies(poetry.get("dev-dependencies", [])),
             extra={k: parse_dependencies(v) for k, v in poetry.get("extras", {}).items()},
+            build=PypiDependency.parse_list(project.pyproject_toml.get("build-system", {}).get("requires", [])),
             indexes=indexes,
         )
 
